unit module OuterModule;
use v6.c;

use InnerModule :ALL :EXPORT;
